# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/run.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import experiment_pb2 as grid_dot_v1_dot_experiment__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/run.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11grid/v1/run.proto\x12\x07grid.v1\x1a\x16grid/v1/metadata.proto\x1a\x18grid/v1/experiment.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\"\x86\x01\n\x03Run\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x11.grid.v1.MetadataR\x08metadata\x12$\n\x04spec\x18\x02 \x01(\x0b\x32\x10.grid.v1.RunSpecR\x04spec\x12*\n\x06status\x18\x03 \x01(\x0b\x32\x12.grid.v1.RunStatusR\x06status\"\xd9\x01\n\x07RunSpec\x12/\n\x08template\x18\x01 \x01(\x0b\x32\x13.grid.v1.ExperimentR\x08template\x12:\n\tgenerator\x18\x02 \x01(\x0b\x32\x1c.grid.v1.ExperimentGeneratorR\tgenerator\x12\x36\n\rdesired_state\x18\x03 \x01(\x0e\x32\x11.grid.v1.RunStateR\x0c\x64\x65siredState\x12)\n\x10pause_automation\x18\x04 \x01(\x08R\x0fpauseAutomation\"\xcc\x01\n\x13\x45xperimentGenerator\x12\x32\n\x08\x65xternal\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x36\n\x0bgrid_search\x18\x02 \x01(\x0b\x32\x13.grid.v1.GridSearchH\x00R\ngridSearch\x12<\n\rrandom_search\x18\x03 \x01(\x0b\x32\x15.grid.v1.RandomSearchH\x00R\x0crandomSearchB\x0b\n\tgenerator\"\xcd\x01\n\x05Param\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x32\n\x08\x65xternal\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\x08\x65xternal\x12\x32\n\x08\x64\x65screte\x18\x03 \x01(\x0b\x32\x14.grid.v1.DiscreteSetH\x00R\x08\x64\x65screte\x12\x38\n\x07uniform\x18\x04 \x01(\x0b\x32\x1c.grid.v1.UniformDistributionH\x00R\x07uniformB\x0e\n\x0c\x64istribution\"%\n\x0b\x44iscreteSet\x12\x16\n\x06values\x18\x01 \x03(\tR\x06values\"Z\n\x13UniformDistribution\x12\x10\n\x03min\x18\x01 \x01(\x02R\x03min\x12\x10\n\x03max\x18\x02 \x01(\x02R\x03max\x12\x1f\n\x0bnum_samples\x18\x03 \x01(\x05R\nnumSamples\"4\n\nGridSearch\x12&\n\x06params\x18\x01 \x03(\x0b\x32\x0e.grid.v1.ParamR\x06params\"U\n\x0cRandomSearch\x12&\n\x06params\x18\x01 \x03(\x0b\x32\x0e.grid.v1.ParamR\x06params\x12\x1d\n\nnum_trials\x18\x02 \x01(\x03R\tnumTrials\"\xda\x01\n\tRunStatus\x12\x41\n\x0b\x65xperiments\x18\x01 \x03(\x0b\x32\x1f.grid.v1.ExperimentSummaryEntryR\x0b\x65xperiments\x12\x43\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0estartTimestamp\x12\x45\n\x10\x66inish_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0f\x66inishTimestamp\"\x7f\n\x16\x45xperimentSummaryEntry\x12\x14\n\x05\x63ount\x18\x01 \x01(\x04R\x05\x63ount\x12\x30\n\x06status\x18\x02 \x01(\x0e\x32\x18.grid.v1.ExperimentStateR\x06status\x12\x1d\n\ncluster_id\x18\x03 \x01(\tR\tclusterId*\xc7\x01\n\x08RunState\x12\x19\n\x15RUN_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11RUN_STATE_PENDING\x10\x01\x12\x14\n\x10RUN_STATE_QUEUED\x10\x02\x12\x15\n\x11RUN_STATE_RUNNING\x10\x03\x12\x17\n\x13RUN_STATE_COMPLETED\x10\x04\x12\x14\n\x10RUN_STATE_FAILED\x10\x05\x12\x16\n\x12RUN_STATE_CANCELED\x10\x06\x12\x15\n\x11RUN_STATE_DELETED\x10\x07\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_experiment__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])

_RUNSTATE = _descriptor.EnumDescriptor(
  name='RunState',
  full_name='grid.v1.RunState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_QUEUED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_RUNNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_COMPLETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_FAILED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_CANCELED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUN_STATE_DELETED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1535,
  serialized_end=1734,
)
_sym_db.RegisterEnumDescriptor(_RUNSTATE)

RunState = enum_type_wrapper.EnumTypeWrapper(_RUNSTATE)
RUN_STATE_UNSPECIFIED = 0
RUN_STATE_PENDING = 1
RUN_STATE_QUEUED = 2
RUN_STATE_RUNNING = 3
RUN_STATE_COMPLETED = 4
RUN_STATE_FAILED = 5
RUN_STATE_CANCELED = 6
RUN_STATE_DELETED = 7



_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='grid.v1.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grid.v1.Run.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='grid.v1.Run.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='spec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.Run.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=275,
)


_RUNSPEC = _descriptor.Descriptor(
  name='RunSpec',
  full_name='grid.v1.RunSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='grid.v1.RunSpec.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='template', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='generator', full_name='grid.v1.RunSpec.generator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='generator', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_state', full_name='grid.v1.RunSpec.desired_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='desiredState', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pause_automation', full_name='grid.v1.RunSpec.pause_automation', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pauseAutomation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=495,
)


_EXPERIMENTGENERATOR = _descriptor.Descriptor(
  name='ExperimentGenerator',
  full_name='grid.v1.ExperimentGenerator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.ExperimentGenerator.external', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grid_search', full_name='grid.v1.ExperimentGenerator.grid_search', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='gridSearch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='random_search', full_name='grid.v1.ExperimentGenerator.random_search', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='randomSearch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='generator', full_name='grid.v1.ExperimentGenerator.generator',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=498,
  serialized_end=702,
)


_PARAM = _descriptor.Descriptor(
  name='Param',
  full_name='grid.v1.Param',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grid.v1.Param.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external', full_name='grid.v1.Param.external', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='external', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='descrete', full_name='grid.v1.Param.descrete', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='descrete', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uniform', full_name='grid.v1.Param.uniform', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uniform', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='distribution', full_name='grid.v1.Param.distribution',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=705,
  serialized_end=910,
)


_DISCRETESET = _descriptor.Descriptor(
  name='DiscreteSet',
  full_name='grid.v1.DiscreteSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='grid.v1.DiscreteSet.values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=912,
  serialized_end=949,
)


_UNIFORMDISTRIBUTION = _descriptor.Descriptor(
  name='UniformDistribution',
  full_name='grid.v1.UniformDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min', full_name='grid.v1.UniformDistribution.min', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='min', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='grid.v1.UniformDistribution.max', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='max', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_samples', full_name='grid.v1.UniformDistribution.num_samples', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numSamples', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1041,
)


_GRIDSEARCH = _descriptor.Descriptor(
  name='GridSearch',
  full_name='grid.v1.GridSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='grid.v1.GridSearch.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1095,
)


_RANDOMSEARCH = _descriptor.Descriptor(
  name='RandomSearch',
  full_name='grid.v1.RandomSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='grid.v1.RandomSearch.params', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='params', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_trials', full_name='grid.v1.RandomSearch.num_trials', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numTrials', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1182,
)


_RUNSTATUS = _descriptor.Descriptor(
  name='RunStatus',
  full_name='grid.v1.RunStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiments', full_name='grid.v1.RunStatus.experiments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='experiments', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_timestamp', full_name='grid.v1.RunStatus.start_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='startTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finish_timestamp', full_name='grid.v1.RunStatus.finish_timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='finishTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=1403,
)


_EXPERIMENTSUMMARYENTRY = _descriptor.Descriptor(
  name='ExperimentSummaryEntry',
  full_name='grid.v1.ExperimentSummaryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='grid.v1.ExperimentSummaryEntry.count', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='count', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='grid.v1.ExperimentSummaryEntry.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='status', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='grid.v1.ExperimentSummaryEntry.cluster_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1405,
  serialized_end=1532,
)

_RUN.fields_by_name['metadata'].message_type = grid_dot_v1_dot_metadata__pb2._METADATA
_RUN.fields_by_name['spec'].message_type = _RUNSPEC
_RUN.fields_by_name['status'].message_type = _RUNSTATUS
_RUNSPEC.fields_by_name['template'].message_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENT
_RUNSPEC.fields_by_name['generator'].message_type = _EXPERIMENTGENERATOR
_RUNSPEC.fields_by_name['desired_state'].enum_type = _RUNSTATE
_EXPERIMENTGENERATOR.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_EXPERIMENTGENERATOR.fields_by_name['grid_search'].message_type = _GRIDSEARCH
_EXPERIMENTGENERATOR.fields_by_name['random_search'].message_type = _RANDOMSEARCH
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(
  _EXPERIMENTGENERATOR.fields_by_name['external'])
_EXPERIMENTGENERATOR.fields_by_name['external'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(
  _EXPERIMENTGENERATOR.fields_by_name['grid_search'])
_EXPERIMENTGENERATOR.fields_by_name['grid_search'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_EXPERIMENTGENERATOR.oneofs_by_name['generator'].fields.append(
  _EXPERIMENTGENERATOR.fields_by_name['random_search'])
_EXPERIMENTGENERATOR.fields_by_name['random_search'].containing_oneof = _EXPERIMENTGENERATOR.oneofs_by_name['generator']
_PARAM.fields_by_name['external'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PARAM.fields_by_name['descrete'].message_type = _DISCRETESET
_PARAM.fields_by_name['uniform'].message_type = _UNIFORMDISTRIBUTION
_PARAM.oneofs_by_name['distribution'].fields.append(
  _PARAM.fields_by_name['external'])
_PARAM.fields_by_name['external'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_PARAM.oneofs_by_name['distribution'].fields.append(
  _PARAM.fields_by_name['descrete'])
_PARAM.fields_by_name['descrete'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_PARAM.oneofs_by_name['distribution'].fields.append(
  _PARAM.fields_by_name['uniform'])
_PARAM.fields_by_name['uniform'].containing_oneof = _PARAM.oneofs_by_name['distribution']
_GRIDSEARCH.fields_by_name['params'].message_type = _PARAM
_RANDOMSEARCH.fields_by_name['params'].message_type = _PARAM
_RUNSTATUS.fields_by_name['experiments'].message_type = _EXPERIMENTSUMMARYENTRY
_RUNSTATUS.fields_by_name['start_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_RUNSTATUS.fields_by_name['finish_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPERIMENTSUMMARYENTRY.fields_by_name['status'].enum_type = grid_dot_v1_dot_experiment__pb2._EXPERIMENTSTATE
DESCRIPTOR.message_types_by_name['Run'] = _RUN
DESCRIPTOR.message_types_by_name['RunSpec'] = _RUNSPEC
DESCRIPTOR.message_types_by_name['ExperimentGenerator'] = _EXPERIMENTGENERATOR
DESCRIPTOR.message_types_by_name['Param'] = _PARAM
DESCRIPTOR.message_types_by_name['DiscreteSet'] = _DISCRETESET
DESCRIPTOR.message_types_by_name['UniformDistribution'] = _UNIFORMDISTRIBUTION
DESCRIPTOR.message_types_by_name['GridSearch'] = _GRIDSEARCH
DESCRIPTOR.message_types_by_name['RandomSearch'] = _RANDOMSEARCH
DESCRIPTOR.message_types_by_name['RunStatus'] = _RUNSTATUS
DESCRIPTOR.message_types_by_name['ExperimentSummaryEntry'] = _EXPERIMENTSUMMARYENTRY
DESCRIPTOR.enum_types_by_name['RunState'] = _RUNSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Run = _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
  'DESCRIPTOR' : _RUN,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Run)
  })
_sym_db.RegisterMessage(Run)

RunSpec = _reflection.GeneratedProtocolMessageType('RunSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNSPEC,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.RunSpec)
  })
_sym_db.RegisterMessage(RunSpec)

ExperimentGenerator = _reflection.GeneratedProtocolMessageType('ExperimentGenerator', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTGENERATOR,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ExperimentGenerator)
  })
_sym_db.RegisterMessage(ExperimentGenerator)

Param = _reflection.GeneratedProtocolMessageType('Param', (_message.Message,), {
  'DESCRIPTOR' : _PARAM,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.Param)
  })
_sym_db.RegisterMessage(Param)

DiscreteSet = _reflection.GeneratedProtocolMessageType('DiscreteSet', (_message.Message,), {
  'DESCRIPTOR' : _DISCRETESET,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DiscreteSet)
  })
_sym_db.RegisterMessage(DiscreteSet)

UniformDistribution = _reflection.GeneratedProtocolMessageType('UniformDistribution', (_message.Message,), {
  'DESCRIPTOR' : _UNIFORMDISTRIBUTION,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UniformDistribution)
  })
_sym_db.RegisterMessage(UniformDistribution)

GridSearch = _reflection.GeneratedProtocolMessageType('GridSearch', (_message.Message,), {
  'DESCRIPTOR' : _GRIDSEARCH,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GridSearch)
  })
_sym_db.RegisterMessage(GridSearch)

RandomSearch = _reflection.GeneratedProtocolMessageType('RandomSearch', (_message.Message,), {
  'DESCRIPTOR' : _RANDOMSEARCH,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.RandomSearch)
  })
_sym_db.RegisterMessage(RandomSearch)

RunStatus = _reflection.GeneratedProtocolMessageType('RunStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNSTATUS,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.RunStatus)
  })
_sym_db.RegisterMessage(RunStatus)

ExperimentSummaryEntry = _reflection.GeneratedProtocolMessageType('ExperimentSummaryEntry', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTSUMMARYENTRY,
  '__module__' : 'grid.v1.run_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ExperimentSummaryEntry)
  })
_sym_db.RegisterMessage(ExperimentSummaryEntry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import whoami_pb2 as grid_dot_v1_dot_whoami__pb2


class AuthenticationServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.WhoAmI = channel.unary_unary(
        '/grid.v1.AuthenticationService/WhoAmI',
        request_serializer=grid_dot_v1_dot_whoami__pb2.WhoAmIRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_whoami__pb2.WhoAmIResponse.FromString,
        )


class AuthenticationServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def WhoAmI(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AuthenticationServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'WhoAmI': grpc.unary_unary_rpc_method_handler(
          servicer.WhoAmI,
          request_deserializer=grid_dot_v1_dot_whoami__pb2.WhoAmIRequest.FromString,
          response_serializer=grid_dot_v1_dot_whoami__pb2.WhoAmIResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.AuthenticationService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from contextlib import contextmanager
import os
from pathlib import Path
from shutil import copytree, ignore_patterns, rmtree
from typing import Optional, Set

import grid.sdk.source_code.gridignore as gridignore
from grid.sdk.source_code.hashing import dirhash
from grid.sdk.utils.tar import tar_path
from grid.sdk.utils.uploader import S3Uploader


class LocalRepository:
    """Utilities for managing local source-code used for creating Runs."""
    cache_location: Path = Path.home() / ".grid" / "cache" / "repositories"

    def __init__(self, path: Path):
        self.path = path

        # cache checksum version
        self._version: Optional[str] = None
        self._files_used_in_checksum: Optional[Set[Path]]

        # create global cache location if it doesn't exist
        if not self.cache_location.exists():
            self.cache_location.mkdir(parents=True, exist_ok=True)

        # clean old cache entries
        self._prune_cache()

    @property
    def _ignore_patterns(self):
        """Generates set of paths from a `.gridignore` file. This is a wrapper for `gridignore.generate()`."""
        return gridignore.generate(src=self.path)

    @property
    def version(self):
        """
        Calculates the checksum of a local path.

        Parameters
        ----------
        path: Path
            Reference to a path.
        """
        # cache value to prevent doing this over again
        if self._version is not None:
            return self._version

        # stores both version and a set with the files used to generate the checksum
        self._files_used_in_checksum, self._version = dirhash(
            path=self.path, algorithm="blake2", ignore=self._ignore_patterns
        )
        return self._version

    @property
    def package_path(self):
        """Location to tarball in local cache."""
        filename = f"{self.version}.tar.gz"
        return self.cache_location / filename

    @contextmanager
    def packaging_session(self) -> Path:
        """Creates a local directory with source code that is used for creating a local source-code package."""
        try:
            session_path = self.cache_location / "packaging_sessions" / self.version
            rmtree(session_path, ignore_errors=True)
            copytree(self.path, session_path, ignore=ignore_patterns(*self._ignore_patterns))

            yield session_path

        finally:
            rmtree(session_path, ignore_errors=True)

    def _prune_cache(self) -> None:
        """Prunes cache; only keeps the 10 most recent items."""
        packages = sorted(self.cache_location.iterdir(), key=os.path.getmtime)
        for package in packages[10:]:
            if package.is_file():
                package.unlink(missing_ok=True)

    def package(self) -> Path:
        """Packages local path using tar."""
        if self.package_path.exists():
            return self.package_path

        # create a packaging session if not available
        with self.packaging_session() as session_path:
            tar_path(source_path=session_path, target_file=self.package_path, compression=True)

        return self.package_path

    def upload(self, url: str) -> None:
        """Uploads package to URL, usually pre-signed URL."""
        uploader = S3Uploader(
            presigned_urls={1: url},
            already_uploaded_parts=[],
            source_file=str(self.package_path),
            name=self.package_path.name,
            total_size=self.package_path.stat().st_size,
            split_size=self.package_path.stat().st_size
        )

        uploader.upload()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/sshpublickey_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import sshpublickey_pb2 as grid_dot_v1_dot_sshpublickey__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/sshpublickey_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"grid/v1/sshpublickey_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x1agrid/v1/sshpublickey.proto\"V\n\x19\x43reateSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1a\x43reateSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"(\n\x16GetSSHPublicKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"T\n\x17GetSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"\x9b\x01\n\x18ListSSHPublicKeysRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\"\xa8\x01\n\x19ListSSHPublicKeysResponse\x12\x39\n\x0csshpublickey\x18\x01 \x03(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"V\n\x19UpdateSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1aUpdateSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"\\\n\x1fUpdateSSHPublicKeyStatusRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"]\n UpdateSSHPublicKeyStatusResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"V\n\x19\x44\x65leteSSHPublicKeyRequest\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"W\n\x1a\x44\x65leteSSHPublicKeyResponse\x12\x39\n\x0csshpublickey\x18\x01 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey\"u\n\x19WatchSSHPublicKeysRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\x12\x17\n\x07user_id\x18\x04 \x01(\tR\x06userId\"\xaa\x01\n\x1aWatchSSHPublicKeysResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x39\n\x0csshpublickey\x18\x03 \x01(\x0b\x32\x15.grid.v1.SSHPublicKeyR\x0csshpublickey2\xc0\x05\n\x13SSHPublicKeyService\x12_\n\x12\x43reateSSHPublicKey\x12\".grid.v1.CreateSSHPublicKeyRequest\x1a#.grid.v1.CreateSSHPublicKeyResponse\"\x00\x12V\n\x0fGetSSHPublicKey\x12\x1f.grid.v1.GetSSHPublicKeyRequest\x1a .grid.v1.GetSSHPublicKeyResponse\"\x00\x12\\\n\x11ListSSHPublicKeys\x12!.grid.v1.ListSSHPublicKeysRequest\x1a\".grid.v1.ListSSHPublicKeysResponse\"\x00\x12_\n\x12UpdateSSHPublicKey\x12\".grid.v1.UpdateSSHPublicKeyRequest\x1a#.grid.v1.UpdateSSHPublicKeyResponse\"\x00\x12o\n\x18UpdateSSHPublicKeyStatus\x12(.grid.v1.UpdateSSHPublicKeyStatusRequest\x1a).grid.v1.UpdateSSHPublicKeyStatusResponse\x12_\n\x12\x44\x65leteSSHPublicKey\x12\".grid.v1.DeleteSSHPublicKeyRequest\x1a#.grid.v1.DeleteSSHPublicKeyResponse\"\x00\x12_\n\x12WatchSSHPublicKeys\x12\".grid.v1.WatchSSHPublicKeysRequest\x1a#.grid.v1.WatchSSHPublicKeysResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_sshpublickey__pb2.DESCRIPTOR,])




_CREATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='CreateSSHPublicKeyRequest',
  full_name='grid.v1.CreateSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.CreateSSHPublicKeyRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=236,
)


_CREATESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='CreateSSHPublicKeyResponse',
  full_name='grid.v1.CreateSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.CreateSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=325,
)


_GETSSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='GetSSHPublicKeyRequest',
  full_name='grid.v1.GetSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetSSHPublicKeyRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=367,
)


_GETSSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='GetSSHPublicKeyResponse',
  full_name='grid.v1.GetSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.GetSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=453,
)


_LISTSSHPUBLICKEYSREQUEST = _descriptor.Descriptor(
  name='ListSSHPublicKeysRequest',
  full_name='grid.v1.ListSSHPublicKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListSSHPublicKeysRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListSSHPublicKeysRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListSSHPublicKeysRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.ListSSHPublicKeysRequest.user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=611,
)


_LISTSSHPUBLICKEYSRESPONSE = _descriptor.Descriptor(
  name='ListSSHPublicKeysResponse',
  full_name='grid.v1.ListSSHPublicKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.ListSSHPublicKeysResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListSSHPublicKeysResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListSSHPublicKeysResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=782,
)


_UPDATESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyRequest',
  full_name='grid.v1.UpdateSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=870,
)


_UPDATESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyResponse',
  full_name='grid.v1.UpdateSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=959,
)


_UPDATESSHPUBLICKEYSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyStatusRequest',
  full_name='grid.v1.UpdateSSHPublicKeyStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyStatusRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1053,
)


_UPDATESSHPUBLICKEYSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateSSHPublicKeyStatusResponse',
  full_name='grid.v1.UpdateSSHPublicKeyStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.UpdateSSHPublicKeyStatusResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1148,
)


_DELETESSHPUBLICKEYREQUEST = _descriptor.Descriptor(
  name='DeleteSSHPublicKeyRequest',
  full_name='grid.v1.DeleteSSHPublicKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.DeleteSSHPublicKeyRequest.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1236,
)


_DELETESSHPUBLICKEYRESPONSE = _descriptor.Descriptor(
  name='DeleteSSHPublicKeyResponse',
  full_name='grid.v1.DeleteSSHPublicKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.DeleteSSHPublicKeyResponse.sshpublickey', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1325,
)


_WATCHSSHPUBLICKEYSREQUEST = _descriptor.Descriptor(
  name='WatchSSHPublicKeysRequest',
  full_name='grid.v1.WatchSSHPublicKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchSSHPublicKeysRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchSSHPublicKeysRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='grid.v1.WatchSSHPublicKeysRequest.user_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='userId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1327,
  serialized_end=1444,
)


_WATCHSSHPUBLICKEYSRESPONSE = _descriptor.Descriptor(
  name='WatchSSHPublicKeysResponse',
  full_name='grid.v1.WatchSSHPublicKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchSSHPublicKeysResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchSSHPublicKeysResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sshpublickey', full_name='grid.v1.WatchSSHPublicKeysResponse.sshpublickey', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sshpublickey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1447,
  serialized_end=1617,
)

_CREATESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_CREATESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_GETSSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_LISTSSHPUBLICKEYSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYSTATUSREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_UPDATESSHPUBLICKEYSTATUSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_DELETESSHPUBLICKEYREQUEST.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_DELETESSHPUBLICKEYRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
_WATCHSSHPUBLICKEYSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHSSHPUBLICKEYSRESPONSE.fields_by_name['sshpublickey'].message_type = grid_dot_v1_dot_sshpublickey__pb2._SSHPUBLICKEY
DESCRIPTOR.message_types_by_name['CreateSSHPublicKeyRequest'] = _CREATESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateSSHPublicKeyResponse'] = _CREATESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['GetSSHPublicKeyRequest'] = _GETSSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['GetSSHPublicKeyResponse'] = _GETSSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['ListSSHPublicKeysRequest'] = _LISTSSHPUBLICKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListSSHPublicKeysResponse'] = _LISTSSHPUBLICKEYSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyRequest'] = _UPDATESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyResponse'] = _UPDATESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyStatusRequest'] = _UPDATESSHPUBLICKEYSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateSSHPublicKeyStatusResponse'] = _UPDATESSHPUBLICKEYSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSSHPublicKeyRequest'] = _DELETESSHPUBLICKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteSSHPublicKeyResponse'] = _DELETESSHPUBLICKEYRESPONSE
DESCRIPTOR.message_types_by_name['WatchSSHPublicKeysRequest'] = _WATCHSSHPUBLICKEYSREQUEST
DESCRIPTOR.message_types_by_name['WatchSSHPublicKeysResponse'] = _WATCHSSHPUBLICKEYSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('CreateSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(CreateSSHPublicKeyRequest)

CreateSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('CreateSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(CreateSSHPublicKeyResponse)

GetSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('GetSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(GetSSHPublicKeyRequest)

GetSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('GetSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(GetSSHPublicKeyResponse)

ListSSHPublicKeysRequest = _reflection.GeneratedProtocolMessageType('ListSSHPublicKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSSHPUBLICKEYSREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListSSHPublicKeysRequest)
  })
_sym_db.RegisterMessage(ListSSHPublicKeysRequest)

ListSSHPublicKeysResponse = _reflection.GeneratedProtocolMessageType('ListSSHPublicKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSSHPUBLICKEYSRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListSSHPublicKeysResponse)
  })
_sym_db.RegisterMessage(ListSSHPublicKeysResponse)

UpdateSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyRequest)

UpdateSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyResponse)

UpdateSSHPublicKeyStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYSTATUSREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyStatusRequest)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyStatusRequest)

UpdateSSHPublicKeyStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateSSHPublicKeyStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESSHPUBLICKEYSTATUSRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateSSHPublicKeyStatusResponse)
  })
_sym_db.RegisterMessage(UpdateSSHPublicKeyStatusResponse)

DeleteSSHPublicKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteSSHPublicKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESSHPUBLICKEYREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteSSHPublicKeyRequest)
  })
_sym_db.RegisterMessage(DeleteSSHPublicKeyRequest)

DeleteSSHPublicKeyResponse = _reflection.GeneratedProtocolMessageType('DeleteSSHPublicKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESSHPUBLICKEYRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteSSHPublicKeyResponse)
  })
_sym_db.RegisterMessage(DeleteSSHPublicKeyResponse)

WatchSSHPublicKeysRequest = _reflection.GeneratedProtocolMessageType('WatchSSHPublicKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSSHPUBLICKEYSREQUEST,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchSSHPublicKeysRequest)
  })
_sym_db.RegisterMessage(WatchSSHPublicKeysRequest)

WatchSSHPublicKeysResponse = _reflection.GeneratedProtocolMessageType('WatchSSHPublicKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSSHPUBLICKEYSRESPONSE,
  '__module__' : 'grid.v1.sshpublickey_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchSSHPublicKeysResponse)
  })
_sym_db.RegisterMessage(WatchSSHPublicKeysResponse)


DESCRIPTOR._options = None

_SSHPUBLICKEYSERVICE = _descriptor.ServiceDescriptor(
  name='SSHPublicKeyService',
  full_name='grid.v1.SSHPublicKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1620,
  serialized_end=2324,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.CreateSSHPublicKey',
    index=0,
    containing_service=None,
    input_type=_CREATESSHPUBLICKEYREQUEST,
    output_type=_CREATESSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.GetSSHPublicKey',
    index=1,
    containing_service=None,
    input_type=_GETSSHPUBLICKEYREQUEST,
    output_type=_GETSSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListSSHPublicKeys',
    full_name='grid.v1.SSHPublicKeyService.ListSSHPublicKeys',
    index=2,
    containing_service=None,
    input_type=_LISTSSHPUBLICKEYSREQUEST,
    output_type=_LISTSSHPUBLICKEYSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.UpdateSSHPublicKey',
    index=3,
    containing_service=None,
    input_type=_UPDATESSHPUBLICKEYREQUEST,
    output_type=_UPDATESSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSSHPublicKeyStatus',
    full_name='grid.v1.SSHPublicKeyService.UpdateSSHPublicKeyStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATESSHPUBLICKEYSTATUSREQUEST,
    output_type=_UPDATESSHPUBLICKEYSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteSSHPublicKey',
    full_name='grid.v1.SSHPublicKeyService.DeleteSSHPublicKey',
    index=5,
    containing_service=None,
    input_type=_DELETESSHPUBLICKEYREQUEST,
    output_type=_DELETESSHPUBLICKEYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchSSHPublicKeys',
    full_name='grid.v1.SSHPublicKeyService.WatchSSHPublicKeys',
    index=6,
    containing_service=None,
    input_type=_WATCHSSHPUBLICKEYSREQUEST,
    output_type=_WATCHSSHPUBLICKEYSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SSHPUBLICKEYSERVICE)

DESCRIPTOR.services_by_name['SSHPublicKeyService'] = _SSHPUBLICKEYSERVICE

# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
import os
from pathlib import Path
from typing import Iterable, List, Optional, Union

from grid.openapi import (
    Externalv1Cluster,
    Externalv1ListClustersResponse,
    V1ClusterState,
    V1ClusterType,
    V1InstanceType,
)
from grid.openapi.api import cluster_service_api
from grid.sdk._gql.queries import experiment_id_from_name, get_grid_user_id, get_runs_lookup_data
from grid.sdk.action import start_run
from grid.sdk.auth import Credentials
from grid.sdk.client import create_swagger_client
from grid.sdk.client.grid_gql import gql_client
from grid.sdk.datastore import Datastore, list_all_available_datastores
from grid.sdk.experiments import Experiment, ExperimentName
from grid.sdk.runs import Run

__all__ = [
    'login', "create_run", "list_runs", "get_run", "cancel_run", "get_experiment_by_name", "get_experiment_by_id",
    "get_build_logs", "get_experiment_logs", "cancel_experiment", "Run", "Datastore", "list_datastores",
    "get_instance_types", "list_clusters"
]


def login(
    username: Optional[str] = None,
    user_id: Optional[str] = None,
    api_key: Optional[str] = None,
    *,
    _url="https://platform.grid.ai"  # noqa - For testing purposes only. not user facing.
):
    """Log in with your grid.ai credentials for usage of the SDK in the running process.

    All parameters are optional. Calling ``login()`` without parameters will check if
    the ``GRID_USER_ID`` and ``GRID_API_KEY`` env vars have been set (using those if
    available), otherwise it will check for the file ``credentials.json`` in the
    machines ``$HOME/.grid`` directory (if it exists).

    If no credentials have been stored, then you must pass in your API key and either
    your username or user id (if you know it). Your user id and API key can be found
    by navigating to *** INSERT INSTRUCTIONS TO FIND KEY HERE ***.

    Parameters
    ----------
    username
        your grid username. This is either be your github username or email address,
        depending on what you use when signing into the grid platform at:
        https://platform.grid.ai

    user_id
        Your grid user id. This can be found by ** INSERT INSTRUCTIONS HERE **
    api_key
        Your grid API key. This can be found by ** INSERT INSTRUCTIONS HERE **
    """
    if user_id and api_key:
        creds = Credentials(user_id=user_id, api_key=api_key)
    elif username and api_key:
        creds = Credentials(user_id=username, api_key=api_key)
        client = gql_client(url=_url + "/graphql", creds=creds)
        user_id = get_grid_user_id(client=client)
        creds = Credentials(user_id=user_id, api_key=api_key)
    elif (username or user_id) or api_key:
        raise ValueError("Either (`user_id` OR `username`) AND `api_key` need to be set, or none set.")
    else:
        creds = Credentials.from_locale()

    os.environ['GRID_USER_ID'] = creds.user_id
    os.environ['GRID_API_KEY'] = creds.api_key
    os.environ['GRID_URL'] = _url
    creds = Credentials.from_locale()
    # warmup cache. can take ~2 sec on first call
    _ = gql_client(url=_url + '/graphql', creds=creds)


def create_run(
    entrypoint: Path,
    script_args: str = '',
    strategy: str = 'grid_search',
    trials: int = None,  # if strategy == random
    framework: str = 'lightning',
    dependency_file: Optional[str] = None,
    instance_type: str = 't2.medium',
    use_spot: bool = False,
    cpus: int = 0,  # if < 1 use max on instance
    gpus: int = 0,  # if < 1 and gpus are on machine, use max on machine.
    memory: Optional[str] = None,
    datastore_name: Optional[str] = None,
    datastore_version: Optional[str] = None,
    datastore_mount_dir: Optional[str] = None,
    scratch_size: Optional[int] = None,
    scratch_mount_path: str = '/tmp/scratch',
    name: Optional[str] = None,
    description: Optional[str] = None,
    cluster: Optional[str] = None,
    localdir: bool = False,
    dockerfile: Optional[str] = None,
    config: Optional[Union[str, Path]] = None
) -> 'Run':
    """Create a run from some configuration

    Parameters
    ----------
    entrypoint: Path,
    script_args: str = '',
    strategy: str = 'grid_search',
    trials: int = None,  # if strategy == random
    framework: str = 'lightning',
    dependency_file: Optional[str] = None,
    instance_type: str = 't2.medium',
    use_spot: bool = False,
    cpus: int = 0,  # if < 1 use max on instance
    gpus: int = 0,  # if < 1 and gpus are on machine, use max on machine.
    memory: Optional[str] = None,
    datastore_name: Optional[str] = None,
    datastore_version: Optional[str] = None,
    datastore_mount_dir: Optional[str] = None,
    scratch_size: Optional[int] = None,
    scratch_mount_path: str = '/tmp/scratch',
    name: Optional[str] = None,
    description: Optional[str] = None,
    cluster: Optional[str] = None,
    localdir: bool = False,
    dockerfile: Optional[str] = None,
    config: Optional[Union[str, Path]] = None

    Returns
    -------
    Run
        the run object which was started
    """
    run_name = start_run(
        entrypoint=entrypoint,
        script_args=script_args,
        strategy=strategy,
        trials=trials,
        framework=framework,
        dependency_file=dependency_file,
        instance_type=instance_type,
        use_spot=use_spot,
        cpus=cpus,
        gpus=gpus,
        memory=memory,
        datastore_name=datastore_name,
        datastore_version=datastore_version,
        datastore_mount_dir=datastore_mount_dir,
        scratch_size=scratch_size,
        scratch_mount_path=scratch_mount_path,
        name=name,
        description=description,
        cluster=cluster,
        localdir=localdir,
        dockerfile=dockerfile,
        config=config
    )
    return get_run(run_name)


def list_runs() -> List[str]:
    """Find the name of every run which you have access to.

    Returns
    -------
    List[str]
        all run names.
    """
    name_ids = get_runs_lookup_data()
    return [d['name'] for d in name_ids]


def get_run(name: str) -> Run:
    """Retrive a Run object by providing its name.

    Parameters
    ----------
    name
        the name of the run you want to retrive.

    Returns
    -------
    Run
        an object whose properties and methods allow you to iterate over
        experiments, ask for build logs, experiment statuses in bulk, , logs, and
        statuses, as well as perform certain administrative operations such
        as canceling runs.

    TODO
    ----
    * Allow users on a team to call ``get_run()`` with a string in the
      format of  ``username:run_name`` to retrieve their teammates' run.
    """
    return Run(name=name)


def cancel_run(name: str) -> List[str]:
    """Cancel all PENDING or RUNNING experiments within a run

    Parameters
    ----------
    name
        name of the run to cancel.

    Returns
    -------
    List[str]
        name of the experiments which have either been cancelled in the
        run or which which have previously reached a terminal state:
        "SUCCEEDED", "FAILED", or "CANCELLED".
    """
    return get_run(name).cancel()


def get_experiment_by_name(name: str) -> Experiment:
    """Retrive an experiment object by providing it's name.

    Parameters
    ----------
    name
        the name of the experiment you want to retrive.

        If you are part of a GridAI Teams account, you can retrieve
        one of your teammates experiments by providing the name in
        the following format: ``username:experiment_name``

    Returns
    -------
    Experiment
        an object whose properties and methods allow you natively ask Grid
        to retrieve up to date information, artifacts metrics, logs, and
        statuses, as well as perform certain administrative operations such
        as canceling a running experiment.
    """
    name = ExperimentName.from_external_format(name)
    exp_id = experiment_id_from_name(name)
    return Experiment._init_via_gql_query(exp_id=exp_id)


def get_experiment_by_id(exp_id: str) -> Experiment:
    """Retrive an experiment object by providing it's unique id.

    The id of an experiment is generated by Grid when the experiment is created.
    It can be found throughout the Experiment and Run objects by querying an
    experiment objects ``.id`` property.

    Parameters
    ----------
    exp_id
        the id of the experiment you want to retrive.

        If you are part of a GridAI Teams account, no change is needed in
        the formatting of the input to retrieve one of your teammates
        experiments. Just passing the id will perform a unique lookup for
        you.

    Returns
    -------
    Experiment
        an object whose properties and methods allow you natively ask Grid
        to retrieve up to date information, artifacts metrics, logs, and
        statuses, as well as perform certain administrative operations such
        as canceling a running experiment.
    """
    return Experiment._init_via_gql_query(exp_id=exp_id)


def get_build_logs(run_name: Optional[str] = None, exp_name: Optional[str] = None) -> Iterable[str]:
    """Output a run or experiment's build logs.

    If the build is currently executing, looping over the iterator will yield
    logs lines for as long as the build continues. If the build is finished,
    then all log lines are available to be iterated over immediatly and no
    wait period is required.

    TODO(rlizzo): how does Teams work here?
                  can you use ``username:experiment_name`` to get build logs?

    Parameters
    ----------
    run_name
        name of a run to retrieve the build logs for.
    exp_name
        name of an experiment to retrieve the build logs for.

    Yields
    -------
    Iterable[str]
        Iterator where each element is a single line of the build log output.
        The first element return is the first line in the build log.

    TODO
    ----
    * Allow users on a team to call ``get_build_logs()`` with a string in
      the format of  ``username:run_name`` to retrieve their teammates' logs.
    """
    if (run_name and exp_name) or (not run_name and not exp_name):
        raise ValueError(
            "One - and only one - of args `run_name`/`exp_name` must be provided.\n"
            f"Recieved run_name={run_name} and exp_name={exp_name}"
        )
    if run_name:
        return get_run(run_name).build_logs()
    else:
        return get_experiment_by_name(exp_name).build_logs()


def get_experiment_logs(name: str) -> List[str]:
    """
    If the experiment is currently executing, looping over the iterator
    will yield logs lines for as long as the experiment continues. If
    the experiment is finished, then all log lines are available to be
    iterated over immediatly and no wait period is required.

    Parameters
    ----------
    name
        name of an experiment to retrieve the logs for.

    Yields
    -------
    Iterable[str]
        Iterator where each element is a single line of the experiment
        stdout log output. The first element return is the first line
        in the build log.

    TODO
    ----
    * Allow users on a team to call ``get_experiment_logs()`` with a string in
      the format of  ``username:experiment_name`` to retrieve their teammates' logs.
    """
    return get_experiment_by_name(name).logs()


def cancel_experiment(name: str) -> str:
    """Cancel a PENDING or RUNNING experiment.

    Parameters
    ----------
    name
        name of the experiment to cancel.

    Returns
    -------
    str
        name of the experiment which has been cancelled.
    """
    return get_experiment_by_name(name).cancel()


def get_instance_types(cluster_id: str) -> List[V1InstanceType]:
    """
    Get the instance types for the given cluster
    """
    api_client = create_swagger_client()
    cluster_api = cluster_service_api.ClusterServiceApi(api_client)
    resp = cluster_api.cluster_service_list_cluster_instance_types(id=cluster_id)
    return resp.instance_types


@dataclass
class ListClusters:
    default_cluster: str
    clusters: List[Externalv1Cluster]


def list_clusters(is_global: bool = False) -> ListClusters:
    """
    List the clusters for the user

    Parameters
    ----------
    is_global:
        Only returns global clusters
    """
    api_client = create_swagger_client()
    cluster_api = cluster_service_api.ClusterServiceApi(api_client)
    if is_global:
        resp = cluster_api.cluster_service_list_clusters(
            phase_in=[V1ClusterState.RUNNING], cluster_type_in=[V1ClusterType.GLOBAL]
        )
    else:
        resp = cluster_api.cluster_service_list_clusters(phase_in=[V1ClusterState.RUNNING])

    return ListClusters(default_cluster=resp.default_cluster, clusters=resp.clusters if resp.clusters else [])


def list_datastores(include_teams: bool = False) -> List[Datastore]:
    """List datastores for user / teams

    Parameters
    ----------
    include_teams:
        if True, returns a list of datastores of the everyone in the team
    """
    return list_all_available_datastores(include_teams=include_teams)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grid.protos.grid.v1 import experiment_details_pb2 as grid_dot_v1_dot_experiment__details__pb2


class ExperimentDetailsServiceStub(object):
  """This is experiment details service which should be implemented in the gridlet
  with control plane optionally proxying it/redirecting to it
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetLogs = channel.unary_unary(
        '/grid.v1.ExperimentDetailsService/GetLogs',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsResponse.FromString,
        )
    self.WatchLogs = channel.unary_stream(
        '/grid.v1.ExperimentDetailsService/WatchLogs',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsResponse.FromString,
        )
    self.ListArtifacts = channel.unary_unary(
        '/grid.v1.ExperimentDetailsService/ListArtifacts',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsResponse.FromString,
        )
    self.WatchArtifacts = channel.unary_stream(
        '/grid.v1.ExperimentDetailsService/WatchArtifacts',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsResponse.FromString,
        )
    self.GetExperimentMetrics = channel.unary_unary(
        '/grid.v1.ExperimentDetailsService/GetExperimentMetrics',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsResponse.FromString,
        )
    self.ListAvailableMetrics = channel.unary_unary(
        '/grid.v1.ExperimentDetailsService/ListAvailableMetrics',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsResponse.FromString,
        )
    self.WatchExperimentMetrics = channel.unary_stream(
        '/grid.v1.ExperimentDetailsService/WatchExperimentMetrics',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsResponse.FromString,
        )
    self.GetExperimentCost = channel.unary_unary(
        '/grid.v1.ExperimentDetailsService/GetExperimentCost',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostResponse.FromString,
        )
    self.GetSessionCost = channel.unary_unary(
        '/grid.v1.ExperimentDetailsService/GetSessionCost',
        request_serializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostRequest.SerializeToString,
        response_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostResponse.FromString,
        )


class ExperimentDetailsServiceServicer(object):
  """This is experiment details service which should be implemented in the gridlet
  with control plane optionally proxying it/redirecting to it
  """

  def GetLogs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchLogs(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListArtifacts(self, request, context):
    """artifacts
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchArtifacts(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetExperimentMetrics(self, request, context):
    """metrics
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ListAvailableMetrics(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def WatchExperimentMetrics(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetExperimentCost(self, request, context):
    """cost
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetSessionCost(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ExperimentDetailsServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetLogs': grpc.unary_unary_rpc_method_handler(
          servicer.GetLogs,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetLogsResponse.SerializeToString,
      ),
      'WatchLogs': grpc.unary_stream_rpc_method_handler(
          servicer.WatchLogs,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchLogsResponse.SerializeToString,
      ),
      'ListArtifacts': grpc.unary_unary_rpc_method_handler(
          servicer.ListArtifacts,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.ListArtifactsResponse.SerializeToString,
      ),
      'WatchArtifacts': grpc.unary_stream_rpc_method_handler(
          servicer.WatchArtifacts,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchArtifactsResponse.SerializeToString,
      ),
      'GetExperimentMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.GetExperimentMetrics,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentMetricsResponse.SerializeToString,
      ),
      'ListAvailableMetrics': grpc.unary_unary_rpc_method_handler(
          servicer.ListAvailableMetrics,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.ListAvailableMetricsResponse.SerializeToString,
      ),
      'WatchExperimentMetrics': grpc.unary_stream_rpc_method_handler(
          servicer.WatchExperimentMetrics,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.WatchExperimentMetricsResponse.SerializeToString,
      ),
      'GetExperimentCost': grpc.unary_unary_rpc_method_handler(
          servicer.GetExperimentCost,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetExperimentCostResponse.SerializeToString,
      ),
      'GetSessionCost': grpc.unary_unary_rpc_method_handler(
          servicer.GetSessionCost,
          request_deserializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostRequest.FromString,
          response_serializer=grid_dot_v1_dot_experiment__details__pb2.GetSessionCostResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grid.v1.ExperimentDetailsService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grid/v1/run_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from grid.protos.grid.v1 import metadata_pb2 as grid_dot_v1_dot_metadata__pb2
from grid.protos.grid.v1 import event_pb2 as grid_dot_v1_dot_event__pb2
from grid.protos.grid.v1 import run_pb2 as grid_dot_v1_dot_run__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grid/v1/run_service.proto',
  package='grid.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/gridai/grid/grid-backend/apis/grid/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19grid/v1/run_service.proto\x12\x07grid.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16grid/v1/metadata.proto\x1a\x13grid/v1/event.proto\x1a\x11grid/v1/run.proto\"2\n\x10\x43reateRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11\x43reateRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"\x1f\n\rGetRunRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"0\n\x0eGetRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"y\n\x0fListRunsRequest\x12%\n\x0e\x63ontinue_token\x18\x01 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x03 \x01(\x03R\x05limit\"\x84\x01\n\x10ListRunsResponse\x12\x1e\n\x03run\x18\x01 \x03(\x0b\x32\x0c.grid.v1.RunR\x03run\x12%\n\x0e\x63ontinue_token\x18\x02 \x01(\tR\rcontinueToken\x12)\n\x10resource_version\x18\x03 \x01(\tR\x0fresourceVersion\"2\n\x10UpdateRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11UpdateRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"8\n\x16UpdateRunStatusRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"9\n\x17UpdateRunStatusResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"2\n\x10\x44\x65leteRunRequest\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"3\n\x11\x44\x65leteRunResponse\x12\x1e\n\x03run\x18\x01 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run\"S\n\x10WatchRunsRequest\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12\x14\n\x05limit\x18\x02 \x01(\x03R\x05limit\"\x86\x01\n\x11WatchRunsResponse\x12)\n\x10resource_version\x18\x01 \x01(\tR\x0fresourceVersion\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x12.grid.v1.EventTypeR\x04type\x12\x1e\n\x03run\x18\x03 \x01(\x0b\x32\x0c.grid.v1.RunR\x03run2\xfa\x03\n\nRunService\x12\x44\n\tCreateRun\x12\x19.grid.v1.CreateRunRequest\x1a\x1a.grid.v1.CreateRunResponse\"\x00\x12;\n\x06GetRun\x12\x16.grid.v1.GetRunRequest\x1a\x17.grid.v1.GetRunResponse\"\x00\x12\x41\n\x08ListRuns\x12\x18.grid.v1.ListRunsRequest\x1a\x19.grid.v1.ListRunsResponse\"\x00\x12\x44\n\tUpdateRun\x12\x19.grid.v1.UpdateRunRequest\x1a\x1a.grid.v1.UpdateRunResponse\"\x00\x12T\n\x0fUpdateRunStatus\x12\x1f.grid.v1.UpdateRunStatusRequest\x1a .grid.v1.UpdateRunStatusResponse\x12\x44\n\tDeleteRun\x12\x19.grid.v1.DeleteRunRequest\x1a\x1a.grid.v1.DeleteRunResponse\"\x00\x12\x44\n\tWatchRuns\x12\x19.grid.v1.WatchRunsRequest\x1a\x1a.grid.v1.WatchRunsResponse0\x01\x42\x32Z0github.com/gridai/grid/grid-backend/apis/grid/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,grid_dot_v1_dot_metadata__pb2.DESCRIPTOR,grid_dot_v1_dot_event__pb2.DESCRIPTOR,grid_dot_v1_dot_run__pb2.DESCRIPTOR,])




_CREATERUNREQUEST = _descriptor.Descriptor(
  name='CreateRunRequest',
  full_name='grid.v1.CreateRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.CreateRunRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=182,
)


_CREATERUNRESPONSE = _descriptor.Descriptor(
  name='CreateRunResponse',
  full_name='grid.v1.CreateRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.CreateRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=235,
)


_GETRUNREQUEST = _descriptor.Descriptor(
  name='GetRunRequest',
  full_name='grid.v1.GetRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grid.v1.GetRunRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=268,
)


_GETRUNRESPONSE = _descriptor.Descriptor(
  name='GetRunResponse',
  full_name='grid.v1.GetRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.GetRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=318,
)


_LISTRUNSREQUEST = _descriptor.Descriptor(
  name='ListRunsRequest',
  full_name='grid.v1.ListRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListRunsRequest.continue_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListRunsRequest.resource_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.ListRunsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=441,
)


_LISTRUNSRESPONSE = _descriptor.Descriptor(
  name='ListRunsResponse',
  full_name='grid.v1.ListRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.ListRunsResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='continue_token', full_name='grid.v1.ListRunsResponse.continue_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continueToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.ListRunsResponse.resource_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=576,
)


_UPDATERUNREQUEST = _descriptor.Descriptor(
  name='UpdateRunRequest',
  full_name='grid.v1.UpdateRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=628,
)


_UPDATERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateRunResponse',
  full_name='grid.v1.UpdateRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=630,
  serialized_end=681,
)


_UPDATERUNSTATUSREQUEST = _descriptor.Descriptor(
  name='UpdateRunStatusRequest',
  full_name='grid.v1.UpdateRunStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunStatusRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=739,
)


_UPDATERUNSTATUSRESPONSE = _descriptor.Descriptor(
  name='UpdateRunStatusResponse',
  full_name='grid.v1.UpdateRunStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.UpdateRunStatusResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=741,
  serialized_end=798,
)


_DELETERUNREQUEST = _descriptor.Descriptor(
  name='DeleteRunRequest',
  full_name='grid.v1.DeleteRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.DeleteRunRequest.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=800,
  serialized_end=850,
)


_DELETERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteRunResponse',
  full_name='grid.v1.DeleteRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.DeleteRunResponse.run', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=903,
)


_WATCHRUNSREQUEST = _descriptor.Descriptor(
  name='WatchRunsRequest',
  full_name='grid.v1.WatchRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchRunsRequest.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='grid.v1.WatchRunsRequest.limit', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=988,
)


_WATCHRUNSRESPONSE = _descriptor.Descriptor(
  name='WatchRunsResponse',
  full_name='grid.v1.WatchRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_version', full_name='grid.v1.WatchRunsResponse.resource_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='grid.v1.WatchRunsResponse.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='run', full_name='grid.v1.WatchRunsResponse.run', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='run', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=991,
  serialized_end=1125,
)

_CREATERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_CREATERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_GETRUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_LISTRUNSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNSTATUSREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_UPDATERUNSTATUSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_DELETERUNREQUEST.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_DELETERUNRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
_WATCHRUNSRESPONSE.fields_by_name['type'].enum_type = grid_dot_v1_dot_event__pb2._EVENTTYPE
_WATCHRUNSRESPONSE.fields_by_name['run'].message_type = grid_dot_v1_dot_run__pb2._RUN
DESCRIPTOR.message_types_by_name['CreateRunRequest'] = _CREATERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateRunResponse'] = _CREATERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetRunRequest'] = _GETRUNREQUEST
DESCRIPTOR.message_types_by_name['GetRunResponse'] = _GETRUNRESPONSE
DESCRIPTOR.message_types_by_name['ListRunsRequest'] = _LISTRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListRunsResponse'] = _LISTRUNSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunRequest'] = _UPDATERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunResponse'] = _UPDATERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateRunStatusRequest'] = _UPDATERUNSTATUSREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunStatusResponse'] = _UPDATERUNSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRunRequest'] = _DELETERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteRunResponse'] = _DELETERUNRESPONSE
DESCRIPTOR.message_types_by_name['WatchRunsRequest'] = _WATCHRUNSREQUEST
DESCRIPTOR.message_types_by_name['WatchRunsResponse'] = _WATCHRUNSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateRunRequest = _reflection.GeneratedProtocolMessageType('CreateRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateRunRequest)
  })
_sym_db.RegisterMessage(CreateRunRequest)

CreateRunResponse = _reflection.GeneratedProtocolMessageType('CreateRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.CreateRunResponse)
  })
_sym_db.RegisterMessage(CreateRunResponse)

GetRunRequest = _reflection.GeneratedProtocolMessageType('GetRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetRunRequest)
  })
_sym_db.RegisterMessage(GetRunRequest)

GetRunResponse = _reflection.GeneratedProtocolMessageType('GetRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.GetRunResponse)
  })
_sym_db.RegisterMessage(GetRunResponse)

ListRunsRequest = _reflection.GeneratedProtocolMessageType('ListRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListRunsRequest)
  })
_sym_db.RegisterMessage(ListRunsRequest)

ListRunsResponse = _reflection.GeneratedProtocolMessageType('ListRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNSRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.ListRunsResponse)
  })
_sym_db.RegisterMessage(ListRunsResponse)

UpdateRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunRequest)
  })
_sym_db.RegisterMessage(UpdateRunRequest)

UpdateRunResponse = _reflection.GeneratedProtocolMessageType('UpdateRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunResponse)
  })
_sym_db.RegisterMessage(UpdateRunResponse)

UpdateRunStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateRunStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNSTATUSREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunStatusRequest)
  })
_sym_db.RegisterMessage(UpdateRunStatusRequest)

UpdateRunStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateRunStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNSTATUSRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.UpdateRunStatusResponse)
  })
_sym_db.RegisterMessage(UpdateRunStatusResponse)

DeleteRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteRunRequest)
  })
_sym_db.RegisterMessage(DeleteRunRequest)

DeleteRunResponse = _reflection.GeneratedProtocolMessageType('DeleteRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.DeleteRunResponse)
  })
_sym_db.RegisterMessage(DeleteRunResponse)

WatchRunsRequest = _reflection.GeneratedProtocolMessageType('WatchRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHRUNSREQUEST,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchRunsRequest)
  })
_sym_db.RegisterMessage(WatchRunsRequest)

WatchRunsResponse = _reflection.GeneratedProtocolMessageType('WatchRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHRUNSRESPONSE,
  '__module__' : 'grid.v1.run_service_pb2'
  # @@protoc_insertion_point(class_scope:grid.v1.WatchRunsResponse)
  })
_sym_db.RegisterMessage(WatchRunsResponse)


DESCRIPTOR._options = None

_RUNSERVICE = _descriptor.ServiceDescriptor(
  name='RunService',
  full_name='grid.v1.RunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1128,
  serialized_end=1634,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateRun',
    full_name='grid.v1.RunService.CreateRun',
    index=0,
    containing_service=None,
    input_type=_CREATERUNREQUEST,
    output_type=_CREATERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRun',
    full_name='grid.v1.RunService.GetRun',
    index=1,
    containing_service=None,
    input_type=_GETRUNREQUEST,
    output_type=_GETRUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRuns',
    full_name='grid.v1.RunService.ListRuns',
    index=2,
    containing_service=None,
    input_type=_LISTRUNSREQUEST,
    output_type=_LISTRUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRun',
    full_name='grid.v1.RunService.UpdateRun',
    index=3,
    containing_service=None,
    input_type=_UPDATERUNREQUEST,
    output_type=_UPDATERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRunStatus',
    full_name='grid.v1.RunService.UpdateRunStatus',
    index=4,
    containing_service=None,
    input_type=_UPDATERUNSTATUSREQUEST,
    output_type=_UPDATERUNSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRun',
    full_name='grid.v1.RunService.DeleteRun',
    index=5,
    containing_service=None,
    input_type=_DELETERUNREQUEST,
    output_type=_DELETERUNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchRuns',
    full_name='grid.v1.RunService.WatchRuns',
    index=6,
    containing_service=None,
    input_type=_WATCHRUNSREQUEST,
    output_type=_WATCHRUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNSERVICE)

DESCRIPTOR.services_by_name['RunService'] = _RUNSERVICE

# @@protoc_insertion_point(module_scope)
